==> xfree86-4.2.0-i386-5.tgz: install/doinst.sh <==
#!/bin/sh
# If the user already has a host.def, then we don't
# want to mess with that:
if [ ! -r usr/X11R6/lib/X11/config/host.def ]; then
  echo > usr/X11R6/lib/X11/config/host.def
fi
( cd etc/X11/rstart/commands ; rm -rf x )
( cd etc/X11/rstart/commands ; ln -sf x11r6 x )
( cd etc/X11/rstart/commands ; rm -rf x11 )
( cd etc/X11/rstart/commands ; ln -sf x11r6 x11 )
( cd etc/X11/rstart/contexts ; rm -rf x )
( cd etc/X11/rstart/contexts ; ln -sf x11r6 x )
( cd etc/X11/rstart/contexts ; rm -rf x11 )
( cd etc/X11/rstart/contexts ; ln -sf x11r6 x11 )
( cd etc/X11/xdm ; rm -rf authdir )
( cd etc/X11/xdm ; ln -sf ../../../var/lib/xdm authdir )
( cd etc/X11/xkb ; rm -rf compiled )
( cd etc/X11/xkb ; ln -sf ../../../var/lib/xkb compiled )
( cd usr/X11R6/bin ; rm -rf X )
( cd usr/X11R6/bin ; ln -sf XFree86 X )
( cd usr/X11R6/lib/X11 ; rm -rf XftConfig )
( cd usr/X11R6/lib/X11 ; ln -sf ../../../../etc/X11/XftConfig XftConfig )
( cd usr/X11R6/lib/X11 ; rm -rf app-defaults )
( cd usr/X11R6/lib/X11 ; ln -sf ../../../../etc/X11/app-defaults app-defaults )
( cd usr/X11R6/lib/X11 ; rm -rf fs )
( cd usr/X11R6/lib/X11 ; ln -sf ../../../../etc/X11/fs fs )
( cd usr/X11R6/lib/X11 ; rm -rf lbxproxy )
( cd usr/X11R6/lib/X11 ; ln -sf ../../../../etc/X11/lbxproxy lbxproxy )
( cd usr/X11R6/lib/X11 ; rm -rf proxymngr )
( cd usr/X11R6/lib/X11 ; ln -sf ../../../../etc/X11/proxymngr proxymngr )
( cd usr/X11R6/lib/X11 ; rm -rf rstart )
( cd usr/X11R6/lib/X11 ; ln -sf ../../../../etc/X11/rstart rstart )
( cd usr/X11R6/lib/X11 ; rm -rf twm )
( cd usr/X11R6/lib/X11 ; ln -sf ../../../../etc/X11/twm twm )
( cd usr/X11R6/lib/X11 ; rm -rf xdm )
( cd usr/X11R6/lib/X11 ; ln -sf ../../../../etc/X11/xdm xdm )
( cd usr/X11R6/lib/X11 ; rm -rf xinit )
( cd usr/X11R6/lib/X11 ; ln -sf ../../../../etc/X11/xinit xinit )
( cd usr/X11R6/lib/X11 ; rm -rf xkb )
( cd usr/X11R6/lib/X11 ; ln -sf ../../../../etc/X11/xkb xkb )
( cd usr/X11R6/lib/X11 ; rm -rf xserver )
( cd usr/X11R6/lib/X11 ; ln -sf ../../../../etc/X11/xserver xserver )
( cd usr/X11R6/lib/X11 ; rm -rf xsm )
( cd usr/X11R6/lib/X11 ; ln -sf ../../../../etc/X11/xsm xsm )
( cd usr/X11R6/lib ; rm -rf libGL.so )
( cd usr/X11R6/lib ; ln -sf libGL.so.1.2 libGL.so )
( cd usr/X11R6/lib ; rm -rf libGL.so.1 )
( cd usr/X11R6/lib ; ln -sf libGL.so.1.2 libGL.so.1 )
( cd usr/X11R6/lib ; rm -rf libGLU.so )
( cd usr/X11R6/lib ; ln -sf libGLU.so.1.3 libGLU.so )
( cd usr/X11R6/lib ; rm -rf libGLU.so.1 )
( cd usr/X11R6/lib ; ln -sf libGLU.so.1.3 libGLU.so.1 )
( cd usr/X11R6/lib ; rm -rf libICE.so )
( cd usr/X11R6/lib ; ln -sf libICE.so.6.3 libICE.so )
( cd usr/X11R6/lib ; rm -rf libICE.so.6 )
( cd usr/X11R6/lib ; ln -sf libICE.so.6.3 libICE.so.6 )
( cd usr/X11R6/lib ; rm -rf libOSMesa.so )
( cd usr/X11R6/lib ; ln -sf libOSMesa.so.3.3 libOSMesa.so )
( cd usr/X11R6/lib ; rm -rf libOSMesa.so.3 )
( cd usr/X11R6/lib ; ln -sf libOSMesa.so.3.3 libOSMesa.so.3 )
( cd usr/X11R6/lib ; rm -rf libSM.so )
( cd usr/X11R6/lib ; ln -sf libSM.so.6.0 libSM.so )
( cd usr/X11R6/lib ; rm -rf libSM.so.6 )
( cd usr/X11R6/lib ; ln -sf libSM.so.6.0 libSM.so.6 )
( cd usr/X11R6/lib ; rm -rf libX11.so )
( cd usr/X11R6/lib ; ln -sf libX11.so.6.2 libX11.so )
( cd usr/X11R6/lib ; rm -rf libX11.so.6 )
( cd usr/X11R6/lib ; ln -sf libX11.so.6.2 libX11.so.6 )
( cd usr/X11R6/lib ; rm -rf libXTrap.so )
( cd usr/X11R6/lib ; ln -sf libXTrap.so.6.4 libXTrap.so )
( cd usr/X11R6/lib ; rm -rf libXTrap.so.6 )
( cd usr/X11R6/lib ; ln -sf libXTrap.so.6.4 libXTrap.so.6 )
( cd usr/X11R6/lib ; rm -rf libXaw.so )
( cd usr/X11R6/lib ; ln -sf libXaw.so.7.0 libXaw.so )
( cd usr/X11R6/lib ; rm -rf libXaw.so.6 )
( cd usr/X11R6/lib ; ln -sf libXaw.so.6.1 libXaw.so.6 )
( cd usr/X11R6/lib ; rm -rf libXaw.so.7 )
( cd usr/X11R6/lib ; ln -sf libXaw.so.7.0 libXaw.so.7 )
( cd usr/X11R6/lib ; rm -rf libXext.so )
( cd usr/X11R6/lib ; ln -sf libXext.so.6.4 libXext.so )
( cd usr/X11R6/lib ; rm -rf libXext.so.6 )
( cd usr/X11R6/lib ; ln -sf libXext.so.6.4 libXext.so.6 )
( cd usr/X11R6/lib ; rm -rf libXfont.so )
( cd usr/X11R6/lib ; ln -sf libXfont.so.1.4 libXfont.so )
( cd usr/X11R6/lib ; rm -rf libXfont.so.1 )
( cd usr/X11R6/lib ; ln -sf libXfont.so.1.4 libXfont.so.1 )
( cd usr/X11R6/lib ; rm -rf libXft.so )
( cd usr/X11R6/lib ; ln -sf libXft.so.1.1 libXft.so )
( cd usr/X11R6/lib ; rm -rf libXft.so.1 )
( cd usr/X11R6/lib ; ln -sf libXft.so.1.1 libXft.so.1 )
( cd usr/X11R6/lib ; rm -rf libXi.so )
( cd usr/X11R6/lib ; ln -sf libXi.so.6.0 libXi.so )
( cd usr/X11R6/lib ; rm -rf libXi.so.6 )
( cd usr/X11R6/lib ; ln -sf libXi.so.6.0 libXi.so.6 )
( cd usr/X11R6/lib ; rm -rf libXmu.so )
( cd usr/X11R6/lib ; ln -sf libXmu.so.6.2 libXmu.so )
( cd usr/X11R6/lib ; rm -rf libXmu.so.6 )
( cd usr/X11R6/lib ; ln -sf libXmu.so.6.2 libXmu.so.6 )
( cd usr/X11R6/lib ; rm -rf libXmuu.so )
( cd usr/X11R6/lib ; ln -sf libXmuu.so.1.0 libXmuu.so )
( cd usr/X11R6/lib ; rm -rf libXmuu.so.1 )
( cd usr/X11R6/lib ; ln -sf libXmuu.so.1.0 libXmuu.so.1 )
( cd usr/X11R6/lib ; rm -rf libXp.so )
( cd usr/X11R6/lib ; ln -sf libXp.so.6.2 libXp.so )
( cd usr/X11R6/lib ; rm -rf libXp.so.6 )
( cd usr/X11R6/lib ; ln -sf libXp.so.6.2 libXp.so.6 )
( cd usr/X11R6/lib ; rm -rf libXpm.so )
( cd usr/X11R6/lib ; ln -sf libXpm.so.4.11 libXpm.so )
( cd usr/X11R6/lib ; rm -rf libXpm.so.4 )
( cd usr/X11R6/lib ; ln -sf libXpm.so.4.11 libXpm.so.4 )
( cd usr/X11R6/lib ; rm -rf libXrandr.so )
( cd usr/X11R6/lib ; ln -sf libXrandr.so.1.0 libXrandr.so )
( cd usr/X11R6/lib ; rm -rf libXrandr.so.1 )
( cd usr/X11R6/lib ; ln -sf libXrandr.so.1.0 libXrandr.so.1 )
( cd usr/X11R6/lib ; rm -rf libXrender.so )
( cd usr/X11R6/lib ; ln -sf libXrender.so.1.1 libXrender.so )
( cd usr/X11R6/lib ; rm -rf libXrender.so.1 )
( cd usr/X11R6/lib ; ln -sf libXrender.so.1.1 libXrender.so.1 )
( cd usr/X11R6/lib ; rm -rf libXt.so )
( cd usr/X11R6/lib ; ln -sf libXt.so.6.0 libXt.so )
( cd usr/X11R6/lib ; rm -rf libXt.so.6 )
( cd usr/X11R6/lib ; ln -sf libXt.so.6.0 libXt.so.6 )
( cd usr/X11R6/lib ; rm -rf libXtst.so )
( cd usr/X11R6/lib ; ln -sf libXtst.so.6.1 libXtst.so )
( cd usr/X11R6/lib ; rm -rf libXtst.so.6 )
( cd usr/X11R6/lib ; ln -sf libXtst.so.6.1 libXtst.so.6 )
( cd usr/X11R6/lib ; rm -rf libdps.so )
( cd usr/X11R6/lib ; ln -sf libdps.so.1.0 libdps.so )
( cd usr/X11R6/lib ; rm -rf libdps.so.1 )
( cd usr/X11R6/lib ; ln -sf libdps.so.1.0 libdps.so.1 )
( cd usr/X11R6/lib ; rm -rf libdpstk.so )
( cd usr/X11R6/lib ; ln -sf libdpstk.so.1.0 libdpstk.so )
( cd usr/X11R6/lib ; rm -rf libdpstk.so.1 )
( cd usr/X11R6/lib ; ln -sf libdpstk.so.1.0 libdpstk.so.1 )
( cd usr/X11R6/lib ; rm -rf libfreetype.so )
( cd usr/X11R6/lib ; ln -sf libfreetype.so.6.2 libfreetype.so )
( cd usr/X11R6/lib ; rm -rf libfreetype.so.6 )
( cd usr/X11R6/lib ; ln -sf libfreetype.so.6.2.0 libfreetype.so.6 )
( cd usr/X11R6/lib ; rm -rf libpsres.so )
( cd usr/X11R6/lib ; ln -sf libpsres.so.1.0 libpsres.so )
( cd usr/X11R6/lib ; rm -rf libpsres.so.1 )
( cd usr/X11R6/lib ; ln -sf libpsres.so.1.0 libpsres.so.1 )
( cd usr/X11R6/lib ; rm -rf libxrx.so )
( cd usr/X11R6/lib ; ln -sf libxrx.so.6.3 libxrx.so )
( cd usr/X11R6/lib ; rm -rf libxrx.so.6 )
( cd usr/X11R6/lib ; ln -sf libxrx.so.6.3 libxrx.so.6 )
( cd usr/include ; rm -rf GL )
( cd usr/include ; ln -sf /usr/X11R6/include/GL GL )
( cd usr/lib ; rm -rf libGL.so )
( cd usr/lib ; ln -sf /usr/X11R6/lib/libGL.so libGL.so )
( cd usr/lib ; rm -rf libGL.so.1 )
( cd usr/lib ; ln -sf /usr/X11R6/lib/libGL.so.1 libGL.so.1 )

==> xfree86-4.2.1-i386-3.tgz: install/doinst.sh <==
#!/bin/sh
# If the user already has a host.def, then we don't
# want to mess with that:
if [ ! -r usr/X11R6/lib/X11/config/host.def ]; then
  echo > usr/X11R6/lib/X11/config/host.def
fi
( cd etc/X11/rstart/commands ; rm -rf x )
( cd etc/X11/rstart/commands ; ln -sf x11r6 x )
( cd etc/X11/rstart/commands ; rm -rf x11 )
( cd etc/X11/rstart/commands ; ln -sf x11r6 x11 )
( cd etc/X11/rstart/contexts ; rm -rf x )
( cd etc/X11/rstart/contexts ; ln -sf x11r6 x )
( cd etc/X11/rstart/contexts ; rm -rf x11 )
( cd etc/X11/rstart/contexts ; ln -sf x11r6 x11 )
( cd etc/X11/xdm ; rm -rf authdir )
( cd etc/X11/xdm ; ln -sf ../../../var/lib/xdm authdir )
( cd etc/X11/xkb ; rm -rf compiled )
( cd etc/X11/xkb ; ln -sf ../../../var/lib/xkb compiled )
( cd usr/X11R6/bin ; rm -rf X )
( cd usr/X11R6/bin ; ln -sf XFree86 X )
( cd usr/X11R6/lib/X11 ; rm -rf XftConfig )
( cd usr/X11R6/lib/X11 ; ln -sf ../../../../etc/X11/XftConfig XftConfig )
( cd usr/X11R6/lib/X11 ; rm -rf app-defaults )
( cd usr/X11R6/lib/X11 ; ln -sf ../../../../etc/X11/app-defaults app-defaults )
( cd usr/X11R6/lib/X11 ; rm -rf fs )
( cd usr/X11R6/lib/X11 ; ln -sf ../../../../etc/X11/fs fs )
( cd usr/X11R6/lib/X11 ; rm -rf lbxproxy )
( cd usr/X11R6/lib/X11 ; ln -sf ../../../../etc/X11/lbxproxy lbxproxy )
( cd usr/X11R6/lib/X11 ; rm -rf proxymngr )
( cd usr/X11R6/lib/X11 ; ln -sf ../../../../etc/X11/proxymngr proxymngr )
( cd usr/X11R6/lib/X11 ; rm -rf rstart )
( cd usr/X11R6/lib/X11 ; ln -sf ../../../../etc/X11/rstart rstart )
( cd usr/X11R6/lib/X11 ; rm -rf twm )
( cd usr/X11R6/lib/X11 ; ln -sf ../../../../etc/X11/twm twm )
( cd usr/X11R6/lib/X11 ; rm -rf xdm )
( cd usr/X11R6/lib/X11 ; ln -sf ../../../../etc/X11/xdm xdm )
( cd usr/X11R6/lib/X11 ; rm -rf xinit )
( cd usr/X11R6/lib/X11 ; ln -sf ../../../../etc/X11/xinit xinit )
( cd usr/X11R6/lib/X11 ; rm -rf xkb )
( cd usr/X11R6/lib/X11 ; ln -sf ../../../../etc/X11/xkb xkb )
( cd usr/X11R6/lib/X11 ; rm -rf xserver )
( cd usr/X11R6/lib/X11 ; ln -sf ../../../../etc/X11/xserver xserver )
( cd usr/X11R6/lib/X11 ; rm -rf xsm )
( cd usr/X11R6/lib/X11 ; ln -sf ../../../../etc/X11/xsm xsm )
( cd usr/X11R6/lib ; rm -rf libGL.so )
( cd usr/X11R6/lib ; ln -sf libGL.so.1.2 libGL.so )
( cd usr/X11R6/lib ; rm -rf libGL.so.1 )
( cd usr/X11R6/lib ; ln -sf libGL.so.1.2 libGL.so.1 )
( cd usr/X11R6/lib ; rm -rf libGLU.so )
( cd usr/X11R6/lib ; ln -sf libGLU.so.1.3 libGLU.so )
( cd usr/X11R6/lib ; rm -rf libGLU.so.1 )
( cd usr/X11R6/lib ; ln -sf libGLU.so.1.3 libGLU.so.1 )
( cd usr/X11R6/lib ; rm -rf libICE.so )
( cd usr/X11R6/lib ; ln -sf libICE.so.6.3 libICE.so )
( cd usr/X11R6/lib ; rm -rf libICE.so.6 )
( cd usr/X11R6/lib ; ln -sf libICE.so.6.3 libICE.so.6 )
( cd usr/X11R6/lib ; rm -rf libOSMesa.so )
( cd usr/X11R6/lib ; ln -sf libOSMesa.so.3.3 libOSMesa.so )
( cd usr/X11R6/lib ; rm -rf libOSMesa.so.3 )
( cd usr/X11R6/lib ; ln -sf libOSMesa.so.3.3 libOSMesa.so.3 )
( cd usr/X11R6/lib ; rm -rf libSM.so )
( cd usr/X11R6/lib ; ln -sf libSM.so.6.0 libSM.so )
( cd usr/X11R6/lib ; rm -rf libSM.so.6 )
( cd usr/X11R6/lib ; ln -sf libSM.so.6.0 libSM.so.6 )
( cd usr/X11R6/lib ; rm -rf libX11.so )
( cd usr/X11R6/lib ; ln -sf libX11.so.6.2 libX11.so )
( cd usr/X11R6/lib ; rm -rf libX11.so.6 )
( cd usr/X11R6/lib ; ln -sf libX11.so.6.2 libX11.so.6 )
( cd usr/X11R6/lib ; rm -rf libXTrap.so )
( cd usr/X11R6/lib ; ln -sf libXTrap.so.6.4 libXTrap.so )
( cd usr/X11R6/lib ; rm -rf libXTrap.so.6 )
( cd usr/X11R6/lib ; ln -sf libXTrap.so.6.4 libXTrap.so.6 )
( cd usr/X11R6/lib ; rm -rf libXaw.so )
( cd usr/X11R6/lib ; ln -sf libXaw.so.7.0 libXaw.so )
( cd usr/X11R6/lib ; rm -rf libXaw.so.6 )
( cd usr/X11R6/lib ; ln -sf libXaw.so.6.1 libXaw.so.6 )
( cd usr/X11R6/lib ; rm -rf libXaw.so.7 )
( cd usr/X11R6/lib ; ln -sf libXaw.so.7.0 libXaw.so.7 )
( cd usr/X11R6/lib ; rm -rf libXext.so )
( cd usr/X11R6/lib ; ln -sf libXext.so.6.4 libXext.so )
( cd usr/X11R6/lib ; rm -rf libXext.so.6 )
( cd usr/X11R6/lib ; ln -sf libXext.so.6.4 libXext.so.6 )
( cd usr/X11R6/lib ; rm -rf libXfont.so )
( cd usr/X11R6/lib ; ln -sf libXfont.so.1.4 libXfont.so )
( cd usr/X11R6/lib ; rm -rf libXfont.so.1 )
( cd usr/X11R6/lib ; ln -sf libXfont.so.1.4 libXfont.so.1 )
( cd usr/X11R6/lib ; rm -rf libXft.so )
( cd usr/X11R6/lib ; ln -sf libXft.so.1.1 libXft.so )
( cd usr/X11R6/lib ; rm -rf libXft.so.1 )
( cd usr/X11R6/lib ; ln -sf libXft.so.1.1 libXft.so.1 )
( cd usr/X11R6/lib ; rm -rf libXi.so )
( cd usr/X11R6/lib ; ln -sf libXi.so.6.0 libXi.so )
( cd usr/X11R6/lib ; rm -rf libXi.so.6 )
( cd usr/X11R6/lib ; ln -sf libXi.so.6.0 libXi.so.6 )
( cd usr/X11R6/lib ; rm -rf libXmu.so )
( cd usr/X11R6/lib ; ln -sf libXmu.so.6.2 libXmu.so )
( cd usr/X11R6/lib ; rm -rf libXmu.so.6 )
( cd usr/X11R6/lib ; ln -sf libXmu.so.6.2 libXmu.so.6 )
( cd usr/X11R6/lib ; rm -rf libXmuu.so )
( cd usr/X11R6/lib ; ln -sf libXmuu.so.1.0 libXmuu.so )
( cd usr/X11R6/lib ; rm -rf libXmuu.so.1 )
( cd usr/X11R6/lib ; ln -sf libXmuu.so.1.0 libXmuu.so.1 )
( cd usr/X11R6/lib ; rm -rf libXp.so )
( cd usr/X11R6/lib ; ln -sf libXp.so.6.2 libXp.so )
( cd usr/X11R6/lib ; rm -rf libXp.so.6 )
( cd usr/X11R6/lib ; ln -sf libXp.so.6.2 libXp.so.6 )
( cd usr/X11R6/lib ; rm -rf libXpm.so )
( cd usr/X11R6/lib ; ln -sf libXpm.so.4.11 libXpm.so )
( cd usr/X11R6/lib ; rm -rf libXpm.so.4 )
( cd usr/X11R6/lib ; ln -sf libXpm.so.4.11 libXpm.so.4 )
( cd usr/X11R6/lib ; rm -rf libXrandr.so )
( cd usr/X11R6/lib ; ln -sf libXrandr.so.1.0 libXrandr.so )
( cd usr/X11R6/lib ; rm -rf libXrandr.so.1 )
( cd usr/X11R6/lib ; ln -sf libXrandr.so.1.0 libXrandr.so.1 )
( cd usr/X11R6/lib ; rm -rf libXrender.so )
( cd usr/X11R6/lib ; ln -sf libXrender.so.1.1 libXrender.so )
( cd usr/X11R6/lib ; rm -rf libXrender.so.1 )
( cd usr/X11R6/lib ; ln -sf libXrender.so.1.1 libXrender.so.1 )
( cd usr/X11R6/lib ; rm -rf libXt.so )
( cd usr/X11R6/lib ; ln -sf libXt.so.6.0 libXt.so )
( cd usr/X11R6/lib ; rm -rf libXt.so.6 )
( cd usr/X11R6/lib ; ln -sf libXt.so.6.0 libXt.so.6 )
( cd usr/X11R6/lib ; rm -rf libXtst.so )
( cd usr/X11R6/lib ; ln -sf libXtst.so.6.1 libXtst.so )
( cd usr/X11R6/lib ; rm -rf libXtst.so.6 )
( cd usr/X11R6/lib ; ln -sf libXtst.so.6.1 libXtst.so.6 )
( cd usr/X11R6/lib ; rm -rf libdps.so )
( cd usr/X11R6/lib ; ln -sf libdps.so.1.0 libdps.so )
( cd usr/X11R6/lib ; rm -rf libdps.so.1 )
( cd usr/X11R6/lib ; ln -sf libdps.so.1.0 libdps.so.1 )
( cd usr/X11R6/lib ; rm -rf libdpstk.so )
( cd usr/X11R6/lib ; ln -sf libdpstk.so.1.0 libdpstk.so )
( cd usr/X11R6/lib ; rm -rf libdpstk.so.1 )
( cd usr/X11R6/lib ; ln -sf libdpstk.so.1.0 libdpstk.so.1 )
( cd usr/X11R6/lib ; rm -rf libpsres.so )
( cd usr/X11R6/lib ; ln -sf libpsres.so.1.0 libpsres.so )
( cd usr/X11R6/lib ; rm -rf libpsres.so.1 )
( cd usr/X11R6/lib ; ln -sf libpsres.so.1.0 libpsres.so.1 )
( cd usr/X11R6/lib ; rm -rf libxrx.so )
( cd usr/X11R6/lib ; ln -sf libxrx.so.6.3 libxrx.so )
( cd usr/X11R6/lib ; rm -rf libxrx.so.6 )
( cd usr/X11R6/lib ; ln -sf libxrx.so.6.3 libxrx.so.6 )
( cd usr/include ; rm -rf GL )
( cd usr/include ; ln -sf /usr/X11R6/include/GL GL )
( cd usr/lib ; rm -rf libGL.so )
( cd usr/lib ; ln -sf /usr/X11R6/lib/libGL.so libGL.so )
( cd usr/lib ; rm -rf libGL.so.1 )
( cd usr/lib ; ln -sf /usr/X11R6/lib/libGL.so.1 libGL.so.1 )
( cd usr/X11R6/lib ; rm -rf libfreetype.so )
( cd usr/X11R6/lib ; ln -sf libfreetype.so.6.2.0 libfreetype.so )
( cd usr/X11R6/lib ; rm -rf libfreetype.so.6 )
( cd usr/X11R6/lib ; ln -sf libfreetype.so.6.2.0 libfreetype.so.6 )
